@@ -4,7 +4,7 @@ use std::process::{Command, Stdio};
 use std::{env, fs};
 
 use clap::ArgMatches;
-use mit_commit_message_lints::mit::{get_config_authors, Authors};
+use mit_commit_message_lints::mit::Authors;
 
 use crate::errors::GitMitConfigError;
 use crate::get_vcs;
@@ -34,8 +34,7 @@ fn run(matches: &ArgMatches) -> Result<(), GitMitConfigError> {
     let is_local = Some("local") == matches.value_of("scope");
     let current_dir = current_dir()?;
     let vcs = get_vcs(is_local, &current_dir)?;
-
-    let vcs_authors = get_config_authors(&vcs)?;
+    let vcs_authors = Authors::try_from(&vcs)?;
 
     let toml: String = all_authors?.merge(&vcs_authors).try_into()?;
 
@@ -63,10 +62,10 @@ fn get_author_config_from_file(matches: &ArgMatches) -> Result<String, GitMitCon
     get_author_file_path(matches)
         .ok_or(GitMitConfigError::AuthorFileNotSet)
         .and_then(|path| match path {
-            "$HOME/.config/git-mit/mit.yml" => config_path(env!("CARGO_PKG_NAME")),
+            "$HOME/.config/git-mit/mit.toml" => config_path(env!("CARGO_PKG_NAME")),
             _ => Ok(path.into()),
         })
-        .and_then(|path| Ok(fs::read_to_string(&path)?))
+        .map(|path| fs::read_to_string(&path).unwrap_or_default())
 }
 
 fn get_author_file_path(matches: &ArgMatches) -> Option<&str> {
